==> foundry_platform_sdk-0.80.0.tar.gz: foundry_platform_sdk-0.80.0/foundry/v1/ontologies/errors/_shared_properties_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import List
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v1.ontologies.models._object_type_api_name import ObjectTypeApiName
from foundry.v1.ontologies.models._shared_property_type_api_name import (
    SharedPropertyTypeApiName,
)  # NOQA


class SharedPropertiesNotFoundParameters(TypedDict):
    """The requested shared property types are not present on every object type."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    objectType: List[ObjectTypeApiName]

    missingSharedProperties: List[SharedPropertyTypeApiName]


@dataclass
class SharedPropertiesNotFound(PalantirRPCException):
    name: Literal["SharedPropertiesNotFound"]
    parameters: SharedPropertiesNotFoundParameters
    error_instance_id: str


__all__ = ["SharedPropertiesNotFound"]

==> foundry_platform_sdk-0.91.0.tar.gz: foundry_platform_sdk-0.91.0/foundry/v1/ontologies/errors/_shared_properties_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import List
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import NotFoundError
from foundry.v1.ontologies.models._object_type_api_name import ObjectTypeApiName
from foundry.v1.ontologies.models._shared_property_type_api_name import (
    SharedPropertyTypeApiName,
)  # NOQA


class SharedPropertiesNotFoundParameters(TypedDict):
    """The requested shared property types are not present on every object type."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    objectType: List[ObjectTypeApiName]

    missingSharedProperties: List[SharedPropertyTypeApiName]


@dataclass
class SharedPropertiesNotFound(NotFoundError):
    name: Literal["SharedPropertiesNotFound"]
    parameters: SharedPropertiesNotFoundParameters
    error_instance_id: str


__all__ = ["SharedPropertiesNotFound"]
